import request from '@/utils/request'

export function home(data) {
  return request({
    url: 'home',
    method: 'get',
    params: data
  })
}
export function withdraw(data) {
  return request({
    url: 'wallet/topUp',
    method: 'post',
    data
  })
}

export function sfBalance(params) {
  return request({
    url: 'user/thirdGame/detail',
    method: 'get',
    params: params
  })
}

export function sfBalanceTransfer(data) {
  return request({
    url: 'user/thirdGame/recycle',
    method: 'post',
    data
  })
}

export function walletdebiting(data) {
  return request({
    url: 'wallet/debiting',
    method: 'post',
    data
  })
}

export function roomcompleted(params) {
  return request({
    url: 'room/completed',
    method: 'post',
    data: params
  })
}

export function roomsetScore(params) {
  return request({
    url: 'room/setScore',
    method: 'post',
    data: params
  })
}

export function withdrawStatus(params) {
  return request({
    url: 'withdraw/setStatus',
    method: 'post',
    data: params
  })
}

export function verifyRecharge(params) {
  return request({
    url: 'wallet/verifyRecharge',
    method: 'post',
    data: params
  })
}

export function setPassword(params) {
  return request({
    url: 'setPassword',
    method: 'post',
    data: params
  })
}
export function setUserPassword(params) {
  return request({
    url: 'user/setPassword ',
    method: 'post',
    data: params
  })
}
export function configset(params) {
  return request({
    url: 'config/set',
    method: 'post',
    data: params
  })
}
export function sendChannelMessage(params) {
  return request({
    url: 'config/sendChannelMessage',
    method: 'post',
    data: params
  })
}
export function menucheck(uri) {
  return request({
    url: 'menu/check',
    method: 'post',
    data: { uri }
  })
}

export function configgetAll(params) {
  return request({
    url: 'config/getAll',
    method: 'get',
    params
  })
}
export function configget(params) {
  return request({
    url: '/config/get',
    method: 'get',
    params
  })
}
export function mineMenu(params) {
  return request({
    url: 'menu/mineMenu',
    method: 'get',
    params
  })
}
export function menutree(params) {
  return request({
    url: 'menu/tree',
    method: 'get',
    params
  })
}
export function roleall(params) {
  return request({
    url: 'role/all',
    method: 'get',
    params
  })
}
export function getPendingTasks(params) {
  return request({
    url: 'wallet/getPendingTasks',
    method: 'get',
    params
  })
}
export function issuebetting(params) {
  return request({
    url: 'issue/betting',
    method: 'post',
    data: params
  })
}
export function issueclose(params) {
  return request({
    url: 'issue/close',
    method: 'post',
    data: params
  })
}
export function issuelotteryDraw(params) {
  return request({
    url: 'issue/lotteryDraw',
    method: 'post',
    data: params
  })
}
export function pcIssuepreDraw(params) {
  return request({
    url: 'pcIssue/preDraw',
    method: 'post',
    data: params
  })
}
export function rebatesubmit(params) {
  return request({
    url: 'rebate/submit',
    method: 'post',
    data: params
  })
}
export function pc28Switch(params) {
  return request({
    url: 'config/pc28Switch',
    method: 'post',
    data: params
  })
}

export function pc28Store(params) {
  return request({
    url: 'config/setField',
    method: 'post',
    data: params
  })
}


export function usermerge(params) {
  return request({
    url: '/user/merge',
    method: 'post',
    data: params
  })
}
export function issuefailure(params) {
  return request({
    url: 'issue/failure',
    method: 'post',
    data: params
  })
}
export function useraddress(params) {
  return request({
    url: 'user/address',
    method: 'get',
    params: params
  })
}

export function walletBankList(params) {
  return request({
    url: 'wallet/bankList',
    method: 'get',
    params: params
  })
}

export function walletAddress(params) {
  return request({
    url: 'wallet/address',
    method: 'get',
    params: params
  })
}

export function paymentOrder(params) {
  return request({
    url: 'paymentOrder/check',
    method: 'get',
    params: params
  })
}

export function audit(params) {
  return request({
    url: 'paymentOrder/audit',
    method: 'post',
    data: params
  })
}

export function withdrawsetNote(params) {
  return request({
    url: 'withdraw/setNote',
    method: 'post',
    data: params
  })
}
export function usersetNote(params) {
  return request({
    url: 'user/setNote',
    method: 'post',
    data: params
  })
}
export function userbanned(params) {
  return request({
    url: 'user/banned',
    method: 'post',
    data: params
  })
}
export function withdrawssetRmbNote(params) {
  return request({
    url: 'withdraw/setRmbNote',
    method: 'post',
    data: params
  })
}
export function finish(params) {
  return request({
    url: 'ActivityUser/finish',
    method: 'post',
    data: params
  })
}
export function gift(params) {
  return request({
    url: 'ActivityUser/gift',
    method: 'post',
    data: params
  })
}
export function menusubmit(params) {
  return request({
    url: 'menu/submit',
    method: 'post',
    data: params
  })
}
export function backflowgrant(params) {
  return request({
    url: 'backflow/grant',
    method: 'post',
    data: params
  })
}
export function menuall(params) {
  return request({
    url: 'menu/all',
    method: 'get',
    params: params
  })
}
export function getChangeTypes(params) {
  return request({
    url: 'wallet/getChangeTypes',
    method: 'get',
    params: params
  })
}

export function operationIndex(params) {
  return request({
    url: 'operation/index',
    method: 'get',
    params: params
  })
}

export function getOrderInfo(params) {
  return request({
    url: 'order/info',
    method: 'get',
    params: params
  })
}

export function getBanners(params) {
  return request({
    url: 'banner/index',
    method: 'get',
    params: params
  })
}

export function updateBanners(params) {
  return request({
    url: 'banner/update',
    method: 'post',
    params: params
  })
}

export function deleteBanners(params) {
  return request({
    url: 'banner/delete',
    method: 'get',
    params: params
  })
}

export function lhcOrderList(params) {
  return request({
    url: 'lhcOrder/list',
    method: 'get',
    params: params
  })
}

export function lhcLotteryList(params) {
  return request({
    url: 'lhcLottery/list',
    method: 'get',
    params: params
  })
}

export function lhcNumberList(params) {
  return request({
    url: 'lhcNumber/list',
    method: 'get',
    params: params
  })
}

export function lhcDetail(params) {
  return request({
    url: 'lhcOrder/info',
    method: 'get',
    params: params
  })
}


export function sportList(params) {
  return request({
    url: 'sport/list',
    method: 'get',
    params: params
  })
}

export function sportInfo(params) {
  return request({
    url: 'sport/info',
    method: 'get',
    params: params
  })
}

export function setSportStatus(params) {
  return request({
    url: 'sport/setStatus',
    method: 'post',
    data: params
  })
}

export function setOddsLocked(params) {
  return request({
    url: 'sport/setOddsLocked',
    method: 'post',
    data: params
  })
}

export function getFixtures(params) {
  return request({
    url: 'sport/getFixtures',
    method: 'post',
    data: params
  })
}

export function orderRefund(params) {
  return request({
    url: 'order/refund',
    method: 'post',
    data: params
  })
}

export function walletOrderDebiting(params) {
  return request({
    url: 'wallet/orderDebiting',
    method: 'post',
    data: params
  })
}

export function walletOrderTopUp(params) {
  return request({
    url: 'wallet/orderTopUp',
    method: 'post',
    data: params
  })
}

export function sportSetValuesLocked(params) {
  return request({
    url: 'sport/setValuesLocked',
    method: 'post',
    data: params
  })
}

export function levelList(params) {
  return request({
    url: 'level/list',
    method: 'get',
    params: params
  })
}

export function levelUpdate(params) {
  return request({
    url: 'level/update',
    method: 'post',
    data: params
  })
}

export function levelDelete(params) {
  return request({
    url: 'level/delete',
    method: 'get',
    params: params
  })
}

export function userLoginLog(params) {
  return request({
    url: 'user/loginLog',
    method: 'get',
    params: params
  })
}

export function yuebaoLog(params) {
  return request({
    url: 'yuebao/log',
    method: 'get',
    params: params
  })
}


export function lhcNumberSetOdds(params) {
  return request({
    url: 'lhcNumber/setOdds',
    method: 'post',
    data: params
  })
}



export function sportOddsList(params) {
  return request({
    url: 'sport/oddsList',
    method: 'get',
    params: params
  })
}


export function sportSetOdds(params) {
  return request({
    url: 'sport/setOdds',
    method: 'post',
    data: params
  })
}


// 1.【财务】充值通道列表
export function getRechargeChannelList(params) {
  return request({
    url: 'rechargeChannel/list',
    method: 'get',
    params: params
  })
}

// 2.【财务】充值通道编辑
export function updateRechargeChannel(params) {
  return request({
    url: 'rechargeChannel/update',
    method: 'post',
    data: params
  })
}

// 3.【财务】充值通道组合列表
export function getRechargeChannelGroupList(params) {
  return request({
    url: 'rechargeChannel/groupList',
    method: 'get',
    params: params
  })
}

// 4.【财务】充值通道组合编辑
export function updateRechargeChannelGroup(params) {
  return request({
    url: 'rechargeChannel/updateGroup',
    method: 'post',
    data: params
  })
}

// 5.【会员列表】设置用户的充值通道
export function setUserRechargeChannelGroup(params) {
  return request({
    url: 'user/setRechargeChannelGroup',
    method: 'post',
    data: params
  })
}

export function getRechargeChannelGetChannel(params) {
  return request({
    url: 'rechargeChannel/getChannel',
    method: 'get',
    params: params
  })
}


export function getLotteryList(params) {
  return request({
    url: 'lhcLottery/list',
    method: 'get',
    params: params
  })
}

export function setOpenCode(params) {
  return request({
    url: 'lhcLottery/setAdvanceCode',
    method: 'post',
    data: params
  })
}



export function getPaymentOrder(params) {
  return request({
    url: 'paymentOrder',
    method: 'get',
    params: params
  })
}


export function paymentOrderSetPayData(params) {
  return request({
    url: 'paymentOrder/setPayData',
    method: 'post',
    data: params
  })
}

export function paymentOrderManual‌Audit(params) {
  return request({
    url: 'paymentOrder/manualAudit',
    method: 'post',
    data: params
  })
}

export function paymentOrderManualRGTXAudit(params) {
  return request({
    url: 'paymentOrder/audit',
    method: 'post',
    data: params
  })
}

export function usdtWithdrawSetIsLocked(params) {
  return request({
    url: 'withdraw/setIsLocked',
    method: 'post',
    data: params
  })
}

export function rmbPaymentOrderSetIsLocked(params) {
  return request({
    url: 'paymentOrder/setIsLocked',
    method: 'post',
    data: params
  })
}

export function getPaymentOrderUnProcessed(params) {
  return request({
    url: 'paymentOrder/unProcessed',
    method: 'get',
    params: params
  })
}

// 足球游戏列表
export function getSportGameList(params) {
  return request({
    url: 'sportGame/list',
    method: 'get',
    params: params
  })
}

// 足球游戏设置赔率
export function setSportGameOdds(params) {
  return request({
    url: 'sportGame/setOdds',
    method: 'post',
    data: params
  })
}

// 足球游戏订单列表
export function getSportGameOrderList(params) {
  return request({
    url: 'sportGameOrder/list',
    method: 'get',
    params: params
  })
}

// 足球游戏订单详情
export function getSportGameOrderInfo(params) {
  return request({
    url: 'sportGameOrder/info',
    method: 'get',
    params: params
  })
}

// 足球游戏订单退款
export function refundSportGameOrder(params) {
  return request({
    url: 'sportGameOrder/refund',
    method: 'post',
    data: params
  })
}

// 极速游戏列表
export function getjisuGameList(params) {
  return request({
    url: 'jisuGame/list',
    method: 'get',
    params: params
  })
}

export function jisuGameSetOdds(params) {
  return request({
    url: 'jisuGame/setOdds',
    method: 'post',
    data: params
  })
}

export function getjisuGameOrderList(params) {
  return request({
    url: 'jisuGameOrder/list',
    method: 'get',
    params: params
  })
}

export function getjisuGameOrderInfo(params) {
  return request({
    url: 'jisuGameOrder/info',
    method: 'get',
    params: params
  })
}

export function jisuGameOrderRefund(params) {
  return request({
    url: 'jisuGameOrder/refund',
    method: 'post',
    data: params
  })
}

export function getJisuLotteryList(params) {
  return request({
    url: 'jisuLottery/list',
    method: 'get',
    params: params
  })
}


export function setJisuOpenCode(params) {
  return request({
    url: 'jisuLottery/setAdvanceCode',
    method: 'post',
    data: params
  })
}

/**
 * 彩票配置
 * @description GET请求
 * @param {Object} params - URL查询参数
 * @returns {Promise} 请求Promise对象
 */
export const gameList = (params) => {
  return request({
    url: 'config/gameList',
    method: 'get',
    params: params
  })
}

/**
 * 彩票配置编辑
 * @description POST请求
 * @param {Object} data - 请求体参数
 * @param {string} data.field - 参数
 * @param {string} data.val - 参数
 * @param {string} data.remark - 参数
 * @returns {Promise} 请求Promise对象
 */
export const setField = (data) => {
  return request({
    url: 'config/setField',
    method: 'post',
    data
  })
}

